# Changelog

## [0.2.2] - 2026-03-08

### Added

* Added help messages to command line arguments

### Changed

* When no options are present prints help message

## [0.2.1] - 2026-03-07

* Dummy Release

## [0.2.0] - 2026-03-07

### Changed

* Changed name from "MCModUpdater" to "mcm"
* Changed command line arguments around

## [0.1.4] - 2026-03-06

### Fixed

* Fixed Downloading latest mod version instead of latest version for the current installed Minecraft version

### Changed

* Removed some of the debug print statements

## [0.1.3] - 2026-03-06

### Added

* Checks for mod updates

## [0.1.2] - 2026-03-06

### Added

* Now can download and install mods
* Can delete mods

### Fixed

* Script executing twice

## [0.1.1] - 2026-03-06

### Added

* Check Modrinth for mod versions
* Get list of mods from config file
* Add mods to config file

## [0.1.0] - 2026-03-03

* Initial Release

[0.1.0]: https://github.com/Josiah-Jarvis/MCModUpdater/releases/tag/0.1.0
[0.1.1]: https://github.com/Josiah-Jarvis/MCModUpdater/releases/tag/0.1.1
[0.1.2]: https://github.com/Josiah-Jarvis/MCModUpdater/releases/tag/0.1.2
[0.1.3]: https://github.com/Josiah-Jarvis/MCModUpdater/releases/tag/0.1.3
[0.1.4]: https://github.com/Josiah-Jarvis/MCModUpdater/releases/tag/0.1.4
[0.2.0]: https://github.com/Josiah-Jarvis/MCModUpdater/releases/tag/0.2.0
[0.2.1]: https://github.com/Josiah-Jarvis/MCModUpdater/releases/tag/0.2.1
[0.2.2]: https://github.com/Josiah-Jarvis/MCModUpdater/releases/tag/0.2.2
